@@ -1,16 +1,15 @@
 /*
  *
- *  This file is part of MUMPS 5.3.5, released
- *  on Thu Oct 22 09:29:08 UTC 2020
+ *  This file is part of MUMPS 5.2.1, released
+ *  on Fri Jun 14 14:46:05 UTC 2019
  *
  *
- *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
- *  released under the CeCILL-C license 
- *  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
- *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
+ *  released under the CeCILL-C license:
+ *  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
  *
  */
 
@@ -29,7 +28,7 @@ extern "C" {
 
 #ifndef MUMPS_VERSION
 /* Protected in case headers of other arithmetics are included */
-#define MUMPS_VERSION "5.3.5"
+#define MUMPS_VERSION "5.2.1"
 #endif
 #ifndef MUMPS_VERSION_MAX_LEN
 #define MUMPS_VERSION_MAX_LEN 30
@@ -49,7 +48,6 @@ typedef struct {
     CMUMPS_REAL    dkeep[230];
     MUMPS_INT8     keep8[150];
     MUMPS_INT      n;
-    MUMPS_INT      nblk;
 
     MUMPS_INT      nz_alloc; /* used in matlab interface to decide if we
                                 free + malloc when we have large variation */
@@ -74,10 +72,6 @@ typedef struct {
     MUMPS_INT      *eltvar;
     CMUMPS_COMPLEX *a_elt;
 
-    /* Matrix by blocks */
-    MUMPS_INT      *blkptr;
-    MUMPS_INT      *blkvar;
-
     /* Ordering, if given by user */
     MUMPS_INT      *perm_in;
 
