@@ -18,5 +18,5 @@
 #define MUMPS_THREAD_AFFINITY_RETURN \
   F_SYMBOL(thread_affinity_return,THREAD_AFFINITY_RETURN)
 void MUMPS_CALL
-MUMPS_THREAD_AFFINITY_RETURN();
+MUMPS_THREAD_AFFINITY_RETURN(void);
 #endif /* MUMPS_THREAD_AFFINITY_H */
